@@ -6,7 +6,7 @@ BEGIN { eval { require warnings; warnings->import } }
 use Getopt::Long ();
 
 use vars qw($VERSION);
-$VERSION = '1.09';	
+$VERSION = '1.09_03';	
 
 eval{ Getopt::Long::Configure qw(
 	posix_default
@@ -17,6 +17,7 @@ eval{ Getopt::Long::Configure qw(
 sub GetOptions {
     my ($no_code) = @_;
     my @expression;
+    my $fullpath = 1;
     Getopt::Long::GetOptions(
 	'-v|verbose'	=> \my $verbose,
 	'-0|null'	=> \my $null,
@@ -25,7 +26,8 @@ sub GetOptions {
 	'-h|?|help'	=> \my $help,
 	'-m|man'	=> \my $man,
 	'-V|version'	=> \my $version,
-	'-d|dir'	=> \my $dir,
+	'-d|filename'	=> sub { undef $fullpath },
+	'-path|fullpath!' => \$fullpath,
 	'-e=s'		=> \@expression,
 	'-E=s'		=>
 	    sub {
@@ -40,13 +42,13 @@ sub GetOptions {
 	input_null	=> $null,
 	no_action	=> $nono,
 	over_write	=> $force,
-	filename_only	=> $dir,
+	filename_only	=> !$fullpath,
 	show_help	=> $help,
 	show_manual	=> $man,
 	show_version	=> $version,
     };
-    return $options if $help or $man or $version;
     return $options if $no_code;
+    return $options if $help or $man or $version;
 	 
     if( @expression ) {
 	$options->{_code} = join "\n", @expression;
