@@ -1,7 +1,7 @@
 use strict;
 
-use File::Spec;
-use File::Path ();
+require File::Spec;
+require File::Path;
 
 sub main_argv { local @ARGV = @_; main () } 
 
@@ -110,4 +110,15 @@ sub diag_rename {
     if( our $print ) { $print =~ s/^/PRINT: /mg; diag $print; }
 }
 
+sub options {
+    local @ARGV = @_;
+    my $opt = do {
+	    require File::Rename::Options; 
+	    File::Rename::Options::GetOptions(1);
+    };
+    die "Bad options '@_'" unless $opt;
+    die "Not options '@ARGV'" if @ARGV;
+    return $opt;
+}
+    
 1;
